import objectdraw.*;
import java.awt.*;

/**
 * Draws a Wire-frame house on the screen.
 * 
 * @author Darren Lim 
 * @version 1.0
 */
public class House
{
    // instance variables - replace the example below with your own
    private Line leftRoofEdge, rightRoofEdge, topOfHouse;
    private FramedRect bodyOfHouse, closedDoor;
    private FramedOval doorKnob;
    private FilledRect openDoor;
    private DrawingCanvas canvas;

    /**
     * Constructor for objects of class House.  The point is assumed to be the top
     * of the house (roof point).  The house is 50 x 50 with the roof 30 pixels high.
     * The roof extends from the body of the house by 10 pixels.  An open door is a FilledRect,
     * and a closed door is a FramedRect with a doorknob
     * 
     * @param point Location of the top point of the roof
     * @param acanvas Drawing canvas for our house 
     */
    public House(Location point, DrawingCanvas acanvas)
    {
        canvas = acanvas;
        //Coordinates of the top of the roof
        double x = point.getX(), y = point.getY();
        //Draw Roof
        leftRoofEdge = new Line(x, y, x - 30, y + 30, canvas);
        rightRoofEdge = new Line(x, y, x + 30, y + 30, canvas);
        topOfHouse = new Line(x + 30, y + 30, x - 30, y + 30, canvas);
        bodyOfHouse = new FramedRect(x - 25, y + 30, 50, 50, canvas);
        closedDoor = new FramedRect(x - 10, y + 50, 20, 30, canvas);
        doorKnob = new FramedOval(x - 8, y + 50 + 15 - 2, 4, 4, canvas);
        openDoor = new FilledRect(x - 10, y + 50, 20, 30, canvas);
        openDoor.setColor(Color.BLACK);
        openDoor.hide();
        
        
    }
    
    /**
     * Returns true if the point parameter is contained by the open door.
     *
     * @param  point Location of a click
     * @return     whether the door was clicked on or not
     */
    public boolean onDoorClick(Location point)
    {
        if (openDoor.contains(point))
            return true;
        return false;
    }
    
    /**
     * Removes all objects from the canvas
     *
     */
    public void removeFromCanvas()
    {
        leftRoofEdge.removeFromCanvas();
        rightRoofEdge.removeFromCanvas();
        topOfHouse.removeFromCanvas();
        bodyOfHouse.removeFromCanvas();
        openDoor.removeFromCanvas();
        doorKnob.removeFromCanvas();
        closedDoor.removeFromCanvas();
        
    }
    
    /**
     * Reverts between an open door (black rectangle) and a closed door (framed rect with
     * a door knob)
     *
     */
    public void changeDoor()
    {
        if (openDoor.isHidden())
        {
            openDoor.show();
            doorKnob.hide();
            closedDoor.hide();            
        }
        else
        {
            openDoor.hide();
            doorKnob.show();
            closedDoor.show();
        }
    }

}
