import objectdraw.*;
/**
 * WindowController for a House Application.  When you click on the screen, you
 * create a house with a roof and door.  If you click on a door, it (opens/closes).
 * 
 * @author Darren Lim
 * @version 1.0
 */
public class HouseWindow extends WindowController
{
    House houseReference;

    /**
     * begin overriden method for our HouseWindow application.  Initializes our house reference
     * to null
     */
    public void begin()
    {
        houseReference = null;
    }

    /**
     * onMouseClick overridden method for our HouseWindow application.  Checks whether we
     * should create a new house if we click on a non-door location on the screen.
     * 
     * @param point  Location of mouse click
     */
    public void onMouseClick(Location point)
    {
       
        if (houseReference == null)
        {
            //First House to be drawn
            houseReference = new House(point, canvas);
        }
        else if (houseReference.onDoorClick(point))
        {
            //Check to see if the active house's door has been clicked on
            houseReference.changeDoor();
        }
        else
        {
            houseReference.removeFromCanvas();
            houseReference = new House(point, canvas);
        }

    }
}
